




# OpticalBackup Scripts for TLS and TLS+AES Encryption

This repository contains scripts for automating directory backups to OpticalBackup servers. The scripts are organized by operating system and encryption method:

- **TLS Encryption**: Ensures secure data transmission to the server using Transport Layer Security.
- **TLS + AES Encryption**: Adds an additional layer of AES-256 encryption for files before uploading, ensuring data remains secure even if intercepted during transmission.

---

## Directory Structure

### tls_and_aes_encryption/
Scripts for TLS and AES-256 encryption. Files are encrypted locally before transmission.

- linux/
  - full_recursive_ob_bk_encryption.py: Python script for Linux.
  - full_recursive_ob_bk_encryption.sh: Bash script for Linux.
- mac/
  - full_recursive_ob_bk_encryption.py: Python script for macOS.
- win/
  - full_recursive_ob_bk_encryption.py: Python script for Windows.

### tls_encryption/
Scripts for TLS encryption only. Data is encrypted during transmission but not locally.

- linux_mac/
  - full_recursive_ob_bk.py: Python script for Linux and macOS.
  - full_recursive_ob_bk.sh: Bash script for Linux and macOS.
- windows/
  - full_recursive_ob_bk.py: Python script for Windows.

---

## Encryption Types

### TLS Encryption
- Uses HTTPS (TLS) to secure data transmission.
- Data is encrypted while in transit to the server.
- Suitable for scenarios where server security is trusted, and local encryption is unnecessary.

### TLS + AES Encryption
- Encrypts files locally using AES-256 encryption before transmission.
- Files are secured during transmission using HTTPS (TLS).
- Ensures that even if intercepted or accessed on the server, files cannot be decrypted without the AES key.
- Recommended for users requiring additional security for highly sensitive data.

---

## How to Configure

### Common Steps
1. **Edit Backup Directories**:
   - Locate the `BACKUP_DIRS` variable in the script.
   - Add the directories you want to back up as a list of paths:
     BACKUP_DIRS = ["/path/to/dir1", "/path/to/dir2"]
   - Ensure all directories exist on your system.

2. **Set Your API Token**:
   - Obtain your API token from the OpticalBackup dashboard: https://app.opticalbackup.com/api-tokens
   - Replace the placeholder in the `AUTH_TOKEN` variable with your token:
     AUTH_TOKEN = "YOUR-API-KEY"

3. **Review Configuration**:
   - Check API endpoints and ensure `API_URL` is correct.

### For AES Encryption Scripts
1. **Provide Your Encryption Key**:
   - Create a file containing your AES encryption key (e.g., `my_key.pem`).
   - Ensure the file contains a single line with the encryption passphrase or key.
   - Specify the key file in the script:
     USER_KEY_FILE = "my_key.pem"

---

## Requirements

### General Requirements
- **Python 3.6+**: Required for all Python scripts.
- **API Key**: Obtain your API token from https://app.opticalbackup.com/api-tokens.

### TLS Encryption
- **Dependencies**:
  - Python:
    pip install requests
  - Bash:
    - curl
    - jq

### TLS + AES Encryption
- **Dependencies**:
  - Python:
    pip install requests
  - OpenSSL:
    - Linux: sudo apt install openssl (Ubuntu/Debian) or sudo dnf install openssl (Fedora)
    - macOS: brew install openssl
    - Windows: Download OpenSSL from https://slproweb.com/products/Win32OpenSSL.html
  - Bash:
    - curl
    - jq
    - openssl

---

## How to Run

### Python Scripts
1. Navigate to the script's directory:
   cd tls_and_aes_encryption/linux
2. Run the script:
   python3 full_recursive_ob_bk_encryption.py

### Bash Scripts
1. Make the script executable:
   chmod +x full_recursive_ob_bk_encryption.sh
2. Run the script:
   ./full_recursive_ob_bk_encryption.sh

---

## Features

1. **Recursive Backup**:
   - All scripts support recursive backups of directories specified in `BACKUP_DIRS`.

2. **File Size Limit Handling**:
   - Automatically skips files larger than the upload limit retrieved from the API.

3. **Detailed Logging**:
   - Logs backup progress and errors in a log file named `backup_report_<timestamp>.log`.

4. **TLS Encryption**:
   - Secures data transmission using HTTPS.

5. **AES-256 Encryption** (for TLS + AES scripts):
   - Provides an additional layer of encryption for local file security.

---

## Contact
For support or questions, contact OpticalBackup at micaelo@opticalbackup.com.
